@@ -257,7 +257,9 @@ if (getRversion() >= "2.15.1") {
 #' Zero (default) implies unfished conditions in year one. Otherwise, this is used to estimate depletion in the first year of the data.
 #' @slot abs_I An integer vector length `nsurvey` to indicate which indices are in absolute magnitude. Use `1` to set `q = 1`, 
 #' otherwise use 0 (default) to estimate q.
-#' @slot I_units An integer vector to indicate whether indices are biomass based (1) or abundance-based (0). By default, all are biomass-based.
+#' @slot I_units An integer vector of length `nsurvey` to indicate whether indices are biomass based (1) or abundance-based (0). By default, all are biomass-based.
+#' @slot I_delta A vector of length `nsurvey` to indicate the timing of the indices within each time step (0-1, for example 0.5 is the midpoint of the year). By default, zero is used.
+#' Use -1 if the survey operates continuously, the availability would be `N * (1 - exp(-Z))/Z`.
 #' @slot age_error A square matrix of `maxage + 1` rows and columns to specify ageing error. The `aa`-th column assigns a proportion of animals of 
 #' true age `aa` to observed age `a` in the `a`-th row. Thus, all rows should sum to 1. Default is an identity matrix (no ageing error).
 #' @slot sel_block For time-varying fleet selectivity (in time blocks), a integer matrix of `nyears` rows and `nfleet` columns to assign a selectivity 
@@ -276,6 +278,6 @@ RCMdata <- setClass("RCMdata", slots = c(Chist = "vectormatrix", C_sd = "vectorm
                                          Index = "vectormatrix", I_sd = "vectormatrix", 
                                          IAA = "array", IAA_ESS = "vectormatrix", IAL = "array", IAL_ESS = "vectormatrix",
                                          C_eq = "vector", C_eq_sd = "vector", E_eq = "vector",
-                                         abs_I = "vector", I_units = "vector", age_error = "matrix", sel_block = "matrix",
+                                         abs_I = "vector", I_units = "vector", I_delta = "vector", age_error = "matrix", sel_block = "matrix",
                                          Misc = "list"))
 
