@@ -61,6 +61,7 @@ Type RCM(objective_function<Type> *obj) {
   DATA_IVECTOR(ivul_type); // Same but for surveys, but can also mirror to B (-4), SSB (-3), or fleet (>0)
   DATA_IVECTOR(abs_I);    // Boolean, whether index is an absolute (fix q = 1) or relative terms (estimate q)
   DATA_IVECTOR(I_units);  // Boolean, whether index is biomass based (= 1) or abundance-based (0)
+  DATA_VECTOR(I_delta);   // Numeric, timing of survey within year (0-1, -1 for mean abundance with (1 - exp(-Z))/Z
 
   DATA_MATRIX(age_error); // Ageing error matrix
 
@@ -91,6 +92,7 @@ Type RCM(objective_function<Type> *obj) {
   DATA_INTEGER(sim_process_error); // Whether to simulate process error (when using the TMB SIMULATE module) 
   DATA_SCALAR(spawn_time_frac);    // Fraction of year when spawning occurs for calculating spawning biomass
   DATA_IVECTOR(est_q);             // Whether to estimate index q (TRUE), otherwise solved analytically (FALSE)
+  DATA_VECTOR(pbc_recdev);          // Proportion of bias correction to apply to log_rec_dev
   
   PARAMETER(R0x);                       // Unfished recruitment
   PARAMETER(transformed_h);             // Steepness
@@ -283,10 +285,10 @@ Type RCM(objective_function<Type> *obj) {
   
   R(0) = R_eq;
   if(est_rec_dev(0)) {
-    Rec_dev(0) = exp(log_rec_dev(0) - 0.5 * tau * tau);
+    Rec_dev(0) = exp(log_rec_dev(0) - 0.5 * pbc_recdev(0) * tau * tau);
     SIMULATE if(sim_process_error) {
       log_rec_dev_sim(0) = rnorm(log_rec_dev(0), tau);
-      Rec_dev(0) = exp(log_rec_dev_sim(0) - 0.5 * tau * tau);
+      Rec_dev(0) = exp(log_rec_dev_sim(0) - 0.5 * pbc_recdev(0) * tau * tau);
     }
     R(0) *= Rec_dev(0);
   }
@@ -320,17 +322,19 @@ Type RCM(objective_function<Type> *obj) {
   // Loop over all other years
   for(int y=0;y<n_y;y++) {
     // Calculate this year's fleet F
-    for(int ff=0;ff<nfleet;ff++) {
-      if(condition(ff) == 0) { // catch
-        if(y != yind_F(ff)) {
-          Type tmp = max_F - F(yind_F(ff),ff) * exp(log_F_dev(y,ff)); // annual F as deviation from F in middle of time series
-          F(y,ff) = CppAD::CondExpLt(tmp, Type(0), max_F - posfun(tmp, Type(0), penalty), F(yind_F(ff),ff) * exp(log_F_dev(y,ff)));
+    if(condition(0) == 1) { // all will be catch2
+      F.row(y) = Newton_F(C_hist, N, M, wt, VB, vul, max_F, y, n_age, nfleet, n_itF, penalty);
+    } else {
+      for(int ff=0;ff<nfleet;ff++) {
+        if(condition(ff) == 0) { // catch
+          if(y != yind_F(ff)) {
+            Type tmp = max_F - F(yind_F(ff),ff) * exp(log_F_dev(y,ff)); // annual F as deviation from F in middle of time series
+            F(y,ff) = CppAD::CondExpLt(tmp, Type(0), max_F - posfun(tmp, Type(0), penalty), F(yind_F(ff),ff) * exp(log_F_dev(y,ff)));
+          }
+        } else if(condition(ff) == 2) { //effort
+          Type tmp = max_F - q_effort(ff) * E_hist(y,ff);
+          F(y,ff) = CppAD::CondExpLt(tmp, Type(0), max_F - posfun(tmp, Type(0), penalty), q_effort(ff) * E_hist(y,ff));
         }
-      } else if(condition(ff) == 1) { //catch2
-        F.row(y) = Newton_F(C_hist, N, M, wt, VB, vul, max_F, y, n_age, nfleet, n_itF, penalty);
-      } else { //effort
-        Type tmp = max_F - q_effort(ff) * E_hist(y,ff);
-        F(y,ff) = CppAD::CondExpLt(tmp, Type(0), max_F - posfun(tmp, Type(0), penalty), q_effort(ff) * E_hist(y,ff));
       }
     }
     
@@ -340,7 +344,7 @@ Type RCM(objective_function<Type> *obj) {
       if(a>0) E(y) += N(y,a) * exp(-spawn_time_frac * Z(y,a)) * fec(y,a);
     }
     
-    // Calculate this year's recruitment and biomass
+    // Calculate this year's recruitment
     if(y>0) {
       if(SR_type == "BH") {
         R(y) = BH_SR(E(y), h, R0, E0_SR);
@@ -351,19 +355,18 @@ Type RCM(objective_function<Type> *obj) {
       }
       
       if(est_rec_dev(y)) {
-        Rec_dev(y) = exp(log_rec_dev(y) - 0.5 * tau * tau);
+        Rec_dev(y) = exp(log_rec_dev(y) - 0.5 * pbc_recdev(y) * tau * tau);
         SIMULATE if(sim_process_error) {
           log_rec_dev_sim(y) = rnorm(log_rec_dev(y), tau);
-          Rec_dev(y) = exp(log_rec_dev_sim(y) - 0.5 * tau * tau);
+          Rec_dev(y) = exp(log_rec_dev_sim(y) - 0.5 * pbc_recdev(y) * tau * tau);
         }
         R(y) *= Rec_dev(y);
       }
       N(y,0) = R(y);
       
-      for(int a=0;a<n_age;a++) {
-        B(y) += N(y,a) * wt(y,a);
-        for(int ff=0;ff<nfleet;ff++) VB(y,ff) += vul(y,a,ff) * N(y,a) * wt(y,a);
-      }
+      // Add age-zero to the total biomass (other age classes calculated in previous year)
+      B(y) += N(y,0) * wt(y,0);
+      for(int ff=0;ff<nfleet;ff++) VB(y,ff) += vul(y,0,ff) * N(y,0) * wt(y,0);
     }
     
     // Calculate this year's CAA, catch, CAL, mean size, then next year's abundance
@@ -394,25 +397,29 @@ Type RCM(objective_function<Type> *obj) {
     } else { //if(msize_type == "weight") 
       for(int ff=0;ff<nfleet;ff++) MWpred(y,ff) = Cpred(y,ff)/CN(y,ff);
     }
+    
+    // Calculate next year's biomass excluding age zero
+    for(int a=1;a<n_age;a++) {
+      B(y+1) += N(y+1,a) * wt(y+1,a);
+      for(int ff=0;ff<nfleet;ff++) VB(y+1,ff) += vul(y+1,a,ff) * N(y+1,a) * wt(y+1,a);
+    }
   }
   
-  // Biomass at beginning of n_y + 1
-  for(int a=1;a<n_age;a++) E(n_y) += N(n_y,a) * fec(n_y,a);
-  
   if(spawn_time_frac > 0) { // Should work properly since spawn_time_frac is identified as DATA_SCALAR
     R(n_y) = R(n_y-1);
-  } else if(SR_type == "BH") {
-    R(n_y) = BH_SR(E(n_y), h, R0, E0_SR);
-  } else if(SR_type == "Ricker") {
-    R(n_y) = Ricker_SR(E(n_y), h, R0, E0_SR);
-  } else { // Mesnil-Rochet
-    R(n_y) = MesnilRochet_SR(E(n_y), MRgamma, MRRmax, MRhinge);
+  } else {
+    if(SR_type == "BH") {
+      R(n_y) = BH_SR(E(n_y), h, R0, E0_SR);
+    } else if(SR_type == "Ricker") {
+      R(n_y) = Ricker_SR(E(n_y), h, R0, E0_SR);
+    } else { // Mesnil-Rochet
+      R(n_y) = MesnilRochet_SR(E(n_y), MRgamma, MRRmax, MRhinge);
+    }
+    for(int a=1;a<n_age;a++) E(n_y) += N(n_y,a) * fec(n_y,a);
   }
   N(n_y,0) = R(n_y);
-  for(int a=0;a<n_age;a++) {
-    B(n_y) += N(n_y,a) * wt(n_y,a);
-    for(int ff=0;ff<nfleet;ff++) VB(n_y,ff) += vul(n_y,a,ff) * N(n_y,a) * wt(n_y,a);
-  }
+  B(n_y) += N(n_y,0) * wt(n_y,0);
+  for(int ff=0;ff<nfleet;ff++) VB(n_y,ff) += vul(n_y,0,ff) * N(n_y,0) * wt(n_y,0);
 
   // Calculate for surveys: q, selectivity, and age/length comps
   vector<Type> iLFS(nsurvey);
@@ -439,7 +446,12 @@ Type RCM(objective_function<Type> *obj) {
   for(int sur=0;sur<nsurvey;sur++) {
     for(int y=0;y<n_y;y++) {
       for(int a=0;a<n_age;a++) {
-        IAAtrue(y,a,sur) = ivul(y,a,sur) * N(y,a);
+        if (I_delta(sur) < 0) {
+          IAAtrue(y,a,sur) = ivul(y,a,sur) * N(y,a) * (1 - exp(-Z(y,a)))/Z(y,a);
+        } else {
+          IAAtrue(y,a,sur) = ivul(y,a,sur) * N(y,a) * exp(-I_delta(sur) * Z(y,a));
+        }
+        
         IN(y,sur) += IAAtrue(y,a,sur);
 
         for(int aa=0;aa<n_age;aa++) IAApred(y,aa,sur) += IAAtrue(y,a,sur) * age_error(a,aa);
@@ -518,8 +530,8 @@ Type RCM(objective_function<Type> *obj) {
     }
     
     for(int y=0;y<n_y;y++) {
-      int check1 = (condition(ff) != 2) && (C_hist(y,ff) > 0);
-      int check2 = (condition(ff) == 2) && (E_hist(y,ff) > 0);
+      int check1 = (condition(ff) != 2) && (C_hist(y,ff) > 0); // Check for F > 0
+      int check2 = (condition(ff) == 2) && (E_hist(y,ff) > 0); // Check for F > 0
       if(check1 || check2) {
         
         if(nll_C && LWT_fleet(ff,0) > 0 && !R_IsNA(asDouble(C_hist(y,ff))) && C_hist(y,ff) > 0) {
